@@ -30,24 +30,34 @@ from .window_manager import *
 from .input import getch, keys
 from .context_managers import alt_buffer, cursor_at, mouse_handler
 
-# This is needeed for pdoc to parse the include statement above.
-__docformat__ = "google"
-
 # Silence warning if running as standalone module
 if "-m" in sys.argv:
     import warnings
 
     warnings.filterwarnings("ignore")
 
-__version__ = "1.1.0"
+__version__ = "2.1.1"
 
 
 def auto(data: Any, **widget_args: Any) -> Optional[Widget | list[Splitter]]:
-    """
-    ### Create widgets from specific data patterns
+    """Creates a widget from specific data structures.
 
     This conversion includes various widget classes, as well as some shorthands for
-    more complex objects.
+    more complex objects.  This method is called implicitly whenever a non-widget is
+    attempted to be added to a Widget.
+
+
+    Args:
+        data: The structure to convert. See below for formats.
+        **widget_args: Arguments passed straight to the widget constructor.
+
+    Returns:
+        The widget or list of widgets created, or None if the passed structure could
+        not be converted.
+
+    <br>
+    <details style="text-align: left">
+        <summary style="all: revert; cursor: pointer">Data structures:</summary>
 
     `pytermgui.widgets.base.Label`:
 
@@ -78,9 +88,7 @@ def auto(data: Any, **widget_args: Any) -> Optional[Widget | list[Splitter]]:
 
     * Created from `list[tuple[str, str], Callable[[str], Any]]`
     * Syntax example: `[("On", "Off"), lambda new_value: ...]`
-
-    This method is called implicitly whenever a non-widget is attempted to be added to
-    a Widget. It returns None in case of a failure
+    </details>
 
     Example:
 
@@ -140,8 +148,8 @@ def auto(data: Any, **widget_args: Any) -> Optional[Widget | list[Splitter]]:
         rows: list[Splitter] = []
 
         for key, value in data.items():
-            left = auto(key, parent_align=WidgetAlignment.LEFT)
-            right = auto(value, parent_align=WidgetAlignment.RIGHT)
+            left = auto(key, parent_align=HorizontalAlignment.LEFT)
+            right = auto(value, parent_align=HorizontalAlignment.RIGHT)
 
             rows.append(Splitter(left, right, **widget_args))
 
