@@ -13,16 +13,17 @@ import re
 import sys
 import signal
 
-from typing import Optional, Any, Union, Callable, Tuple
+from typing import Optional, Any, Union, Callable, Tuple, Pattern
 from dataclasses import dataclass, fields
 from enum import Enum, auto as _auto
 from sys import stdout as _stdout
 from string import hexdigits
-from subprocess import run as _run, Popen as _Popen
-from os import name as _name, get_terminal_size, system
+from os import name as _name, system
+from shutil import get_terminal_size
 
 from .input import getch
 
+_IS_NT = _name == "nt"
 
 __all__ = [
     "Color",
@@ -70,6 +71,12 @@ __all__ = [
 ]
 
 
+RE_MOUSE: dict[str, Pattern] = {
+    "decimal_xterm": re.compile(r"<(\d{1,2})\;(\d{1,3})\;(\d{1,3})(\w)"),
+    "decimal_urxvt": re.compile(r"(\d{1,2})\;(\d{1,3})\;(\d{1,3})()"),
+}
+
+
 class Color:
     """Class to store various color utilities
 
@@ -84,6 +91,20 @@ class Color:
     - `str`: Name of one of the registered named colors. See `Color.names`.
     - `#rrggbb`: RGB hex string. Note: alpha values are not supported.
     - `tuple[int, int]`: Tuple of RGB colors, each 0-256.
+
+    When calling an instance of the class, the following args are set:
+
+    Args:
+        text: The string that will be colored.
+        color: The color specifier.
+        reset_color: A boolean that determines whether the returned value should
+            end with a reset code. Defaults to True.
+
+    Returns:
+        The colored string.
+
+    Raises:
+        NotImplementedError: Unrecognized color specifier was passed.
     """
 
     ColorType = Union[int, str, Tuple[int, int, int]]
@@ -112,10 +133,15 @@ class Color:
     `pytermgui.parser.MarkupLanguage.alias`."""
 
     def __init__(self, layer: int = 0) -> None:
-        """Initialize object
+        """Initialize Color object.
 
-        `layer` can be either 0 or 1. This value determines whether the instance
-        will represent foreground or background colors."""
+        Args:
+            layer: One of [0, 1]. Objects instantiated with 0 will represent foreground
+                colors, while objects instantiated with 1 will display background ones.
+
+        Raises:
+            NotImplementedError: Invalid layer.
+        """
 
         if layer not in [0, 1]:
             raise NotImplementedError(f"Layer {layer} can only be one of [0, 1].")
@@ -124,7 +150,16 @@ class Color:
 
     @staticmethod
     def translate_hex(color: str) -> tuple[int, int, int]:
-        """Translate hex string of format #RRGGBB into an RGB tuple of integers"""
+        """Translates a hex string of format #RRGGBB into an RGB tuple of integers.
+
+        Args:
+            color: The hexadecimal string to convert. Must follow the format #RRGGBB, where
+                capitalization is optional.
+
+        Returns:
+            A tuple of integers, 0-255 each, standing for red, green and blue values in that
+            order.
+        """
 
         if color.startswith("#"):
             color = color[1:]
@@ -137,15 +172,7 @@ class Color:
         return rgb[0], rgb[1], rgb[2]
 
     def __call__(self, text: str, color: ColorType, reset_color: bool = True) -> str:
-        """Color a piece of text using `color`.
-
-        The color can be one of 4 formats:
-            - str colorname:   One of the predifined named colors. See the names dict.
-            - int 0-256:       One of the 256 terminal colors.
-            - str #RRGGBB:     CSS-style HEX string, without alpha.
-            - tuple (0-256, 0-256, 0-256): Tuple of integers, representing an RGB color.
-
-        If `reset_color` is set a reset sequence is inserted at the end."""
+        """Colors a piece of text. See help(Color) for more info."""
 
         # convert hex string to tuple[int, int, int]
         if isinstance(color, str) and all(
@@ -185,87 +212,82 @@ class Color:
 
 
 foreground = Color()
-"""`Color` instance to setting foreground colors"""
+"""`Color` instance for setting foreground colors."""
 
-background = Color(layer=1)
-"""`Color` instance to setting background colors"""
+background = Color(1)
+"""`Color` instance for setting background colors."""
 
 
-def screen_size() -> tuple[int, int]:
-    """Get screen size using the os module
-
-    This is technically possible using a method of moving the
-    cursor to an impossible location, and using `report_cursor()`
-    to get where the position was clamped. This however messes
-    with the cursor position and printing gets a bit glitchy."""
-
-    try:
-        width, height = get_terminal_size()
-        return (width, height)
-
-    except OSError as error:
-        if error.errno in (9, 25):
-            return 0, 0
-
-        raise
-
-
-class _Terminal:
-    """A class to store & access data about a terminal"""
+class Terminal:
+    """A class to store & access data about a terminal."""
 
     RESIZE = 0
+    """Event sent out when the terminal has been resized.
+
+    Arguments passed:
+    - New size: tuple[int, int]
+    """
+
     margins = [0, 0, 0, 0]
+    """Not quite sure what this does at the moment."""
 
     def __init__(self) -> None:
-        """Initialize object"""
+        """Initialize `_Terminal` class."""
 
         self.origin: tuple[int, int] = (1, 1)
         self.size: tuple[int, int] = self._get_size()
         self._listeners: dict[int, list[Callable[..., Any]]] = {}
 
-        # TODO: Windows doesn't support SIGWINCH, is there another alternative?
         if hasattr(signal, "SIGWINCH"):
             signal.signal(signal.SIGWINCH, self._update_size)
 
+        # TODO: Support SIGWINCH on Windows.
+
     def _call_listener(self, event: int, data: Any) -> None:
-        """Call event callback is one is found."""
+        """Calls callbacks for event.
+
+        Args:
+            event: A terminal event.
+            data: Arbitrary data passed to the callback.
+        """
 
         if event in self._listeners:
             for callback in self._listeners[event]:
                 callback(data)
 
     def _get_size(self) -> tuple[int, int]:
-        """Get screen size while substracting the origin position"""
+        """Gets the screen size with origin substracted."""
 
-        # This always has len() == 2, but mypy can't see that.
-        return tuple(val - org for val, org in zip(screen_size(), self.origin))  # type: ignore
+        size = get_terminal_size()
+        return (size[0] - self.origin[0], size[1] - self.origin[1])
 
     def _update_size(self, *_: Any) -> None:
-        """Resize terminal when SIGWINCH occurs.
-
-        Note:
-            SIGWINCH is not supported on Windows, so this isn't called."""
+        """Resize terminal when SIGWINCH occurs, and call listeners."""
 
         self.size = self._get_size()
         self._call_listener(self.RESIZE, self.size)
 
     @property
     def width(self) -> int:
-        """Get width of terminal"""
+        """Gets the current width of the terminal."""
 
         return self.size[0]
 
     @property
     def height(self) -> int:
-        """Get height of terminal"""
+        """Gets the current height of the terminal."""
 
         return self.size[1]
 
     def subscribe(self, event: int, callback: Callable[..., Any]) -> None:
-        """Subscribe a callback function to an event
+        """Subcribes a callback to be called when event occurs.
 
-        The callback takes an event-specific argument payload:
-            RESIZE: tuple[int, int] - New screen size"""
+        Args:
+            event: The terminal event that calls callback.
+            callback: The callable to be called. The signature of this
+                callable is dependent on the event. See the documentation
+                of the specific event for more information.
+        """
 
         if not event in self._listeners:
             self._listeners[event] = []
@@ -273,86 +295,81 @@ class _Terminal:
         self._listeners[event].append(callback)
 
     def fill(self, color: int = 0, flush: bool = True) -> None:
-        """Fill entire terminal with a color"""
+        """Fills the entire terminal with the given color.
+
+        This is more of a debug function than anything, as performance is not the
+        greatest.
+
+        Args:
+            color: An integer for the color to fill in. Must be in the 0-255 xterm
+                color range.
+            flush: Whether stdout should be flushed. Defaults to True, but setting
+                it False can be beneficial for performance, as long as you flush in
+                some other place.
+        """
 
         for height in range(self.height):
             sys.stdout.write(
-                f"\033[{height};0H" + background(" " * (self.width - 1), color)
+                f"\033[{height};0H"
+                + background(" " * (self.width - 1), color)
+                + ("\n" if flush else "")
             )
 
-        if flush:
-            sys.stdout.flush()
 
-
-terminal = _Terminal()
-
-# helpers
-def _tput(command: list[str]) -> None:
-    """Shorthand for tput calls"""
-
-    waited_commands = ["clear", "smcup", "cup"]
-
-    command.insert(0, "tput")
-    str_command = [str(c) for c in command]
-
-    if command[1] in waited_commands:
-        _run(str_command, check=True)
-        return
-
-    # A with statement here would result in `pass`, so is unnecessary.
-    _Popen(str_command)  # pylint: disable=consider-using-with
+terminal = Terminal()
+"""Terminal instance that should be used pretty much always."""
 
 
 def is_interactive() -> bool:
-    """Determine whether shell is interactive.
+    """Determines whether shell is interactive.
 
-    A shell is interactive if it is run from `python3` or `python3 -i`."""
+    A shell is interactive if it is run from `python3` or `python3 -i`.
+    """
 
     return hasattr(sys, "ps1")
 
 
 # screen commands
 def save_screen() -> None:
-    """Save the contents of the screen, wipe.
+    """Saves the contents of the screen, and wipes it.
 
-    Use `restore_screen()` to get them back."""
+    Use `restore_screen()` to get them back.
+    """
 
-    # print("\x1b[?47h")
-    _tput(["smcup"])
+    print("\x1b[?47h")
 
 
 def restore_screen() -> None:
-    """Restore the contents of the screen saved by `save_screen()`"""
+    """Restores the contents of the screen saved by `save_screen()`."""
 
-    # print("\x1b[?47l")
-    _tput(["rmcup"])
+    print("\x1b[?47l")
 
 
 def set_alt_buffer() -> None:
-    """Start alternate buffer
-
-    Note: This buffer is unscrollable."""
+    """Starts an alternate buffer."""
 
     print("\x1b[?1049h")
 
 
 def unset_alt_buffer() -> None:
-    """Return to main buffer from alt, restoring its original state"""
+    """Returns to main buffer, restoring its original state."""
 
     print("\x1b[?1049l")
 
 
 def clear(what: str = "screen") -> None:
-    """Clear specified region
+    """Clears the specified screen region.
+
+    Args:
+        what: The specifier defining the screen area.
 
     Available options:
-    - `screen` - clear whole screen and go to origin
-    - `bos` - clear screen from cursor backwards
-    - `eos` - clear screen from cursor forwards
-    - `line` - clear line and go to beginning
-    - `bol` - clear line from cursor backwards
-    - `eol` - clear line from cursor forwards
-
+    * screen: clear whole screen and go to origin
+    * bos: clear screen from cursor backwards
+    * eos: clear screen from cursor forwards
+    * line: clear line and go to beginning
+    * bol: clear line from cursor backwards
+    * eol: clear line from cursor forwards
     """
 
     commands = {
@@ -369,37 +386,43 @@ def clear(what: str = "screen") -> None:
 
 # cursor commands
 def hide_cursor() -> None:
-    """Stop printing cursor"""
+    """Stops printing the cursor."""
 
-    # _tput(['civis'])
     print("\x1b[?25l")
 
 
 def show_cursor() -> None:
-    """Start printing cursor"""
+    """Starts printing the cursor."""
 
-    # _tput(['cvvis'])
     print("\x1b[?25h")
 
 
 def save_cursor() -> None:
-    """Save cursor position.
+    """Saves the current cursor position.
 
-    Use `restore_cursor()` to restore it."""
+    Use `restore_cursor()` to restore it.
+    """
 
-    # _tput(['sc'])
     _stdout.write("\x1b[s")
 
 
 def restore_cursor() -> None:
-    """Restore cursor position saved by `save_cursor()`"""
+    """Restore cursor position as saved by `save_cursor`."""
 
-    # _tput(['rc'])
     _stdout.write("\x1b[u")
 
 
 def report_cursor() -> tuple[int, int] | None:
-    """Get position of cursor"""
+    """Gets position of cursor.
+
+    Returns:
+        A tuple of integers, (columns, rows), describing the
+        current (printing) cursor's position. Returns None if
+        this could not be determined.
+
+        Note that this position is **not** the mouse position. See
+        `report_mouse` if that is what you are interested in.
+    """
 
     print("\x1b[6n")
     chars = getch()
@@ -412,113 +435,154 @@ def report_cursor() -> tuple[int, int] | None:
 
 
 def move_cursor(pos: tuple[int, int]) -> None:
-    """Move cursor to `pos`.
+    """Moves the cursor.
 
-    Note:
-        This does not flush the terminal for performance reasons. You
-        can do it manually with `sys.stdout.flush()`."""
+    Args:
+        pos: Tuple of (columns, rows) that the cursor will be moved to.
+
+    This does not flush the terminal for performance reasons. You
+    can do it manually with `sys.stdout.flush()`.
+    """
 
     posx, posy = pos
     _stdout.write(f"\x1b[{posy};{posx}H")
 
 
 def cursor_up(num: int = 1) -> None:
-    """Move cursor up by `num` lines.
+    """Moves the cursor up by `num` lines.
 
+    Args:
+        num: How many lines the cursor should move by. Must be positive,
+            to move in the opposite direction use `cursor_down`.
     Note:
         This does not flush the terminal for performance reasons. You
-        can do it manually with `sys.stdout.flush()`."""
+        can do it manually with `sys.stdout.flush()`.
+    """
 
     _stdout.write(f"\x1b[{num}A")
 
 
 def cursor_down(num: int = 1) -> None:
-    """Move cursor down by `num` lines.
+    """Moves the cursor up by `num` lines.
 
+    Args:
+        num: How many lines the cursor should move by. Must be positive,
+            to move in the opposite direction use `cursor_up`.
     Note:
         This does not flush the terminal for performance reasons. You
-        can do it manually with `sys.stdout.flush()`."""
+        can do it manually with `sys.stdout.flush()`.
+    """
 
     _stdout.write(f"\x1b[{num}B")
 
 
 def cursor_right(num: int = 1) -> None:
-    """Move cursor left by `num` cols.
+    """Moves the cursor right by `num` lines.
 
+    Args:
+        num: How many characters the cursor should move by. Must be positive,
+            to move in the opposite direction use `cursor_left`.
     Note:
         This does not flush the terminal for performance reasons. You
-        can do it manually with `sys.stdout.flush()`."""
+        can do it manually with `sys.stdout.flush()`.
+    """
 
     _stdout.write(f"\x1b[{num}C")
 
 
 def cursor_left(num: int = 1) -> None:
-    """Move cursor left by `num` cols.
+    """Moves the cursor left by `num` lines.
 
+    Args:
+        num: How many characters the cursor should move by. Must be positive,
+            to move in the opposite direction use `cursor_right`.
     Note:
         This does not flush the terminal for performance reasons. You
-        can do it manually with `sys.stdout.flush()`."""
+        can do it manually with `sys.stdout.flush()`.
+    """
 
     _stdout.write(f"\x1b[{num}D")
 
 
 def cursor_next_line(num: int = 1) -> None:
-    """Move cursor to beginning of `num`-th line down.
+    """Moves the cursor to the beginning of the `num`-th line downwards.
 
+    Args:
+        num: The amount the cursor should move by. Must be positive, to move
+            in the opposite direction use `cursor_prev_line`.
     Note:
         This does not flush the terminal for performance reasons. You
-        can do it manually with `sys.stdout.flush()`."""
+        can do it manually with `sys.stdout.flush()`.
+    """
 
     _stdout.write(f"\x1b[{num}E")
 
 
 def cursor_prev_line(num: int = 1) -> None:
-    """Move cursor to beginning of `num`-th line down.
+    """Moves the cursor to the beginning of the `num`-th line upwards.
 
+    Args:
+        num: The amount the cursor should move by. Must be positive, to move
+            in the opposite direction use `cursor_next_line`.
     Note:
         This does not flush the terminal for performance reasons. You
-        can do it manually with `sys.stdout.flush()`."""
+        can do it manually with `sys.stdout.flush()`.
+    """
 
     _stdout.write(f"\x1b[{num}F")
 
 
 def cursor_column(num: int = 0) -> None:
-    """Move cursor to `num`-th column in the current line.
+    """Moves the cursor to the `num`-th character of the current line.
+
+    Args:
+        num: The new cursor position.
 
     Note:
         This does not flush the terminal for performance reasons. You
-        can do it manually with `sys.stdout.flush()`."""
+        can do it manually with `sys.stdout.flush()`.
+    """
 
     _stdout.write(f"\x1b[{num}G")
 
 
 def cursor_home() -> None:
-    """Move cursor to `terminal.origin`.
+    """Moves cursor to `terminal.origin`.
 
     Note:
         This does not flush the terminal for performance reasons. You
-        can do it manually with `sys.stdout.flush()`."""
+        can do it manually with `sys.stdout.flush()`.
+    """
 
     _stdout.write("\x1b[H")
 
 
 def set_mode(mode: Union[str, int], write: bool = True) -> str:
-    """Set terminal display mode
+    """Sets terminal display mode.
 
-    Available options:
-    - 0 - `reset`
-    - 1 - `bold`
-    - 2 - `dim`
-    - 3 - `italic`
-    - 4 - `underline`
-    - 5 - `blink`
-    - 7 - `inverse`
-    - 8 - `invisible`
-    - 9 - `strikethrough`
-    - 53 - `overline`
+    This is better left internal. To use these modes, you can call their
+    specific functions, such as `bold("text")` or `italic("text")`.
 
-    You can use both the digit and text forms, though you should really be
-    using one of the specific setters, like `bold` or `italic`."""
+    Args:
+        mode: One of the available modes. Strings and integers both work.
+        write: Boolean that determines whether the output should be written
+            to stdout.
+
+    Returns:
+        A string that sets the given mode.
+
+    Available modes:
+        - 0: reset
+        - 1: bold
+        - 2: dim
+        - 3: italic
+        - 4: underline
+        - 5: blink
+        - 7: inverse
+        - 8: invisible
+        - 9: strikethrough
+        - 53: overline
+    """
 
     options = {
         "reset": 0,
@@ -544,9 +608,11 @@ def set_mode(mode: Union[str, int], write: bool = True) -> str:
 
 
 def set_echo() -> None:
-    """Start echoing user input
+    """Starts echoing of user input.
 
-    Note: This is only available on POSIX"""
+    Note:
+        This is currently only available on POSIX.
+    """
 
     if not _name == "posix":
         return
@@ -555,9 +621,11 @@ def set_echo() -> None:
 
 
 def unset_echo() -> None:
-    """Stop echoing user input
+    """Stops echoing of user input.
 
-    Note: This is only available on POSIX"""
+    Note:
+        This is currently only available on POSIX.
+    """
 
     if not _name == "posix":
         return
@@ -569,30 +637,28 @@ class MouseAction(Enum):
     """An enumeration of all the polled mouse actions"""
 
     LEFT_CLICK = _auto()
-    """Start of a left button action sequence"""
+    """Start of a left button action sequence."""
 
     LEFT_DRAG = _auto()
-    """Mouse moved while left button was held down"""
+    """Mouse moved while left button was held down."""
 
     RIGHT_CLICK = _auto()
-    """Start of a right button action sequence"""
+    """Start of a right button action sequence."""
 
     RIGHT_DRAG = _auto()
-    """Mouse moved while right button was held down"""
+    """Mouse moved while right button was held down."""
 
     SCROLL_UP = _auto()
-    """Mouse wheel or touchpad scroll upwards"""
+    """Mouse wheel or touchpad scroll upwards."""
 
     SCROLL_DOWN = _auto()
-    """Mouse wheel or touchpad scroll downwards"""
+    """Mouse wheel or touchpad scroll downwards."""
 
     HOVER = _auto()
-    """Mouse moved without clicking
-
-    Note: This only gets registered when hover events are listened to"""
+    """Mouse moved without clicking."""
 
     RELEASE = _auto()
-    """Mouse button released; end of any and all mouse action sequences"""
+    """Mouse button released; end of any and all mouse action sequences."""
 
 
 @dataclass
@@ -641,26 +707,38 @@ class MouseEvent:
 def report_mouse(
     event: str, method: Optional[str] = "decimal_xterm", stop: bool = False
 ) -> None:
-    """Start reporting mouse events.
+    """Starts reporting of mouse events.
 
-    Options:
-    - `press`
-    - `highlight`
-    - `press_hold`
-    - `hover`
+    You can specify multiple events to report on.
 
-    Methods:
-    - `None`:          Limited in coordinates, not recommended.
-    - `decimal_xterm`: Default, most universal
-    - `decimal_urxvt`: Older, less compatible
-    - `decimal_utf8`:  Apparently not too stable
+    Args:
+        event: The type of event to report on. See below for options.
+        method: The method of reporting to use. See below for options.
+        stop: If set to True, the stopping code is written to stdout.
 
-    More information <a href='https://stackoverflow.com/a/5970472'>here</a>.
+    Raises:
+        NotImplementedError: The given event is not supported.
 
     Note:
         If you need this functionality, you're probably better off using the wrapper
         `pytermgui.context_managers.mouse_handler`, which allows listening on multiple
         events, gives a translator method and handles exceptions.
+
+    Possible events:
+        - **press**: Report when the mouse is clicked, left or right button.
+        - **highlight**: Report highlighting.
+        - **press_hold**: Report with a left or right click, as well as both
+            left & right drag and release.
+        - **hover**: Report even when no active action is done, only the mouse
+          is moved.
+
+    Methods:
+        - **None**: Non-decimal xterm method. Limited in coordinates.
+        - **decimal_xterm**: The default setting. Most universally supported.
+        - **decimal_urxvt**: Older, less compatible, but useful on some systems.
+        - **decimal_utf8**:  Apparently not too stable.
+
+    More information <a href='https://stackoverflow.com/a/5970472'>here</a>.
     """
 
     if event == "press":
@@ -700,14 +778,21 @@ def report_mouse(
 
 
 def translate_mouse(code: str, method: str) -> list[MouseEvent | None] | None:
-    """Translate the output of produced by setting report_mouse codes into MouseEvent-s.
+    """Translates the output of produced by setting `report_mouse` into MouseEvents.
 
-    This currently only supports `decimal_xterm` and `decimal_urvxt`. See `report_mouse` for more
-    information."""
+    This method currently only supports `decimal_xterm` and `decimal_urxvt`.
+
+    Args:
+        code: The string of mouse code(s) to translate.
+        method: The reporting method to translate. One of [`decimal_xterm`, `decimal_urxvt`].
+
+    Returns:
+        A list of optional mouse events obtained from the code argument. If the code was malformed,
+        and no codes could be determined None is returned.
+    """
 
     mouse_codes = {
         "decimal_xterm": {
-            "pattern": re.compile(r"<(\d{1,2})\;(\d{1,3})\;(\d{1,3})(\w)"),
             "0M": MouseAction.LEFT_CLICK,
             "0m": MouseAction.RELEASE,
             "2": MouseAction.RIGHT_CLICK,
@@ -718,19 +803,18 @@ def translate_mouse(code: str, method: str) -> list[MouseEvent | None] | None:
             "65": MouseAction.SCROLL_DOWN,
         },
         "decimal_urxvt": {
-            "pattern": re.compile(r"(\d{1,2})\;(\d{1,3})\;(\d{1,3})()"),
             "32": MouseAction.LEFT_CLICK,
             "34": MouseAction.RIGHT_CLICK,
             "35": MouseAction.RELEASE,
             "64": MouseAction.LEFT_DRAG,
-            "66": MouseAction.RIGHT_CLICK,
+            "66": MouseAction.RIGHT_DRAG,
             "96": MouseAction.SCROLL_UP,
             "97": MouseAction.SCROLL_DOWN,
         },
     }
 
     mapping = mouse_codes[method]
-    pattern = mapping["pattern"]
+    pattern: Pattern = RE_MOUSE[method]
 
     events: list[MouseEvent | None] = []
     for sequence in code.split("\x1b"):
@@ -738,7 +822,7 @@ def translate_mouse(code: str, method: str) -> list[MouseEvent | None] | None:
             continue
 
         matches = list(pattern.finditer(sequence))
-        if matches == []:
+        if len(matches) == 0:
             return None
 
         for match in matches:
@@ -763,74 +847,129 @@ def translate_mouse(code: str, method: str) -> list[MouseEvent | None] | None:
 
 # shorthand functions
 def print_to(pos: tuple[int, int], *args: Any, **kwargs: Any) -> None:
-    """Print text to given `pos`.
+    """Prints text to given `pos`.
 
-    This passes through all arguments (except for `pos`) to the `print`
-    method."""
+    Note:
+        This method passes through all arguments (except for `pos`) to the `print`
+        method.
+    """
 
     move_cursor(pos)
     print(*args, **kwargs, end="", flush=True)
 
 
 def reset() -> str:
-    """Reset printing mode"""
+    """Resets printing mode.
+
+    Args:
+        reset_style: Boolean that determines whether a reset
+            character should be appended to the end of the
+            string.
+    """
 
     return set_mode("reset", False)
 
 
 def bold(text: str, reset_style: Optional[bool] = True) -> str:
-    """Return text in bold"""
+    """Returns text in bold.
+
+    Args:
+        reset_style: Boolean that determines whether a reset character should
+            be appended to the end of the string.
+    """
 
     return set_mode("bold", False) + text + (reset() if reset_style else "")
 
 
 def dim(text: str, reset_style: Optional[bool] = True) -> str:
-    """Return text in dim"""
+    """Returns text in dim.
+
+    Args:
+        reset_style: Boolean that determines whether a reset character should
+            be appended to the end of the string.
+    """
 
     return set_mode("dim", False) + text + (reset() if reset_style else "")
 
 
 def italic(text: str, reset_style: Optional[bool] = True) -> str:
-    """Return text in italic"""
+    """Returns text in italic.
+
+    Args:
+        reset_style: Boolean that determines whether a reset character should
+            be appended to the end of the string.
+    """
 
     return set_mode("italic", False) + text + (reset() if reset_style else "")
 
 
 def underline(text: str, reset_style: Optional[bool] = True) -> str:
-    """Return text underlined"""
+    """Returns text underlined.
+
+    Args:
+        reset_style: Boolean that determines whether a reset character should
+            be appended to the end of the string.
+    """
 
     return set_mode("underline", False) + text + (reset() if reset_style else "")
 
 
 def blink(text: str, reset_style: Optional[bool] = True) -> str:
-    """Return text blinking"""
+    """Returns text blinking.
+
+    Args:
+        reset_style: Boolean that determines whether a reset character should
+            be appended to the end of the string.
+    """
 
     return set_mode("blink", False) + text + (reset() if reset_style else "")
 
 
 def inverse(text: str, reset_style: Optional[bool] = True) -> str:
-    """Return text inverse-colored"""
+    """Returns text inverse-colored.
+
+    Args:
+        reset_style: Boolean that determines whether a reset character should
+            be appended to the end of the string.
+    """
 
     return set_mode("inverse", False) + text + (reset() if reset_style else "")
 
 
 def invisible(text: str, reset_style: Optional[bool] = True) -> str:
-    """Return text as invisible
+    """Returns text as invisible.
 
-    Note: This isn't very widely supported"""
+    Args:
+        reset_style: Boolean that determines whether a reset character should
+            be appended to the end of the string.
+
+    Note:
+        This isn't very widely supported.
+    """
 
     return set_mode("invisible", False) + text + (reset() if reset_style else "")
 
 
 def strikethrough(text: str, reset_style: Optional[bool] = True) -> str:
-    """Return text as strikethrough"""
+    """Return text as strikethrough.
+
+    Args:
+        reset_style: Boolean that determines whether a reset character should
+            be appended to the end of the string.
+    """
 
     return set_mode("strikethrough", False) + text + (reset() if reset_style else "")
 
 
 def overline(text: str, reset_style: Optional[bool] = True) -> str:
-    """Return text overlined
+    """Return text overlined.
 
-    Note: This isnt' very widely supported"""
+    Args:
+        reset_style: Boolean that determines whether a reset character should
+            be appended to the end of the string.
+
+    Note:
+        This isnt' very widely supported.
+    """
 
     return set_mode("overline", False) + text + (reset() if reset_style else "")
