@@ -50,11 +50,10 @@ import time
 import signal
 from threading import Thread
 from enum import Enum, auto as _auto
-from dataclasses import dataclass, field
-from typing import Optional, Any, cast
+from typing import Optional, Any
 
 # https://github.com/python/mypy/issues/4930
-from .widgets.base import Container
+from .widgets.layouts import Container
 
 from .widgets import (
     MarkupFormatter,
@@ -64,12 +63,12 @@ from .widgets import (
 
 from .input import getch
 from .parser import markup
-from .helpers import strip_ansi
-from .exceptions import LineLengthError
-from .enums import CenteringPolicy, SizePolicy
-from .context_managers import alt_buffer, mouse_handler, MouseTranslator
+from .helpers import strip_ansi, real_length
+from .enums import CenteringPolicy, SizePolicy, Overflow
+from .context_managers import alt_buffer, mouse_handler, MouseTranslator, cursor_at
 from .ansi_interface import (
     terminal,
+    background,
     MouseEvent,
     move_cursor,
     MouseAction,
@@ -80,7 +79,7 @@ __all__ = ["Window", "WindowManager"]
 
 
 class Edge(Enum):
-    """Enum for window edges"""
+    """Enum for window edges."""
 
     LEFT = _auto()
     TOP = _auto()
@@ -88,122 +87,60 @@ class Edge(Enum):
     BOTTOM = _auto()
 
 
-@dataclass
-class Rect:
-    """A class representing a screen region"""
-
-    start: tuple[int, int]
-    end: tuple[int, int]
-
-    left: int = field(init=False)
-    right: int = field(init=False)
-    top: int = field(init=False)
-    bottom: int = field(init=False)
-
-    def __post_init__(self) -> None:
-        """Set up extra instance attributes"""
-
-        self.left = self.start[0]
-        self.right = self.end[0] - 1
-        self.top = self.start[1]
-        self.bottom = self.end[1] + 3
-
-        self.values = self.left, self.top, self.right, self.bottom
-
-    @classmethod
-    def from_widget(cls, widget: Widget) -> Rect:
-        """Create a Rect from a widget"""
-
-        start = widget.pos
-        end = start[0] + widget.width, start[1] + widget.height
-        return cls(start, end)
-
-    @classmethod
-    def from_tuple(cls, tpl: tuple[int, int, int, int]) -> Rect:
-        """Create a Rect from a tuple of points"""
-
-        startx, starty, endx, endy = tpl
-        return cls((startx, starty), (endx, endy))
-
-    @property
-    def width(self) -> int:
-        """Calculate width of rect"""
-
-        return self.end[0] - self.start[0]
-
-    @property
-    def height(self) -> int:
-        """Calculate height of rect"""
-
-        return self.end[1] - self.start[1]
-
-    def collides_with(self, other: Rect) -> bool:
-        """Calculate collision with other Rect object"""
-
-        return (
-            self.left < other.right
-            and self.right > other.left
-            and self.top > other.bottom
-            and self.bottom < other.top
-        )
-
-    def contains(self, pos: tuple[int, int]) -> bool:
-        """Determine if position is contained within this area"""
-
-        return self.left <= pos[0] <= self.right and self.top <= pos[1] <= self.bottom
-
-    def show(self) -> None:
-        """Draw rect on screen"""
-
-        root = Container(width=self.right - self.left)
-        root += self.debug()
-        root.forced_width = self.right - self.left
-        root.forced_height = self.top - self.bottom
-        root.pos = self.start
-
-        root.print()
-
-    def debug(self) -> str:
-        """Show identifiable debug information"""
-
-        return str(Widget.debug(cast(Widget, self)))
-
-
 class Window(Container):
-    """A class representing a window
+    """A class representing a window.
 
     Windows are essentially fancy `pytermgui.widgets.Container`-s. They build on top of them
     to store and display various widgets, while allowing some custom functionality.
     """
 
     is_bindable = True
+    overflow = Overflow.HIDE
     size_policy = SizePolicy.STATIC
 
     allow_fullscreen = False
-    """When a window is allowed fullscreen its manager will try to set it so before each frame"""
+    """When a window is allowed fullscreen its manager will try to set it so before each frame."""
 
     title = ""
-    """Title shown in left-top corner"""
+    """Title shown in left-top corner."""
 
     is_static = False
-    """Static windows cannot be moved using the mouse"""
+    """Static windows cannot be moved using the mouse."""
 
     is_modal = False
-    """Modal windows stay on top of every other window and block interactions with other windows"""
+    """Modal windows stay on top of every other window and block interactions with other windows."""
 
     is_noblur = False
-    """No-blur windows will always appear to stay in focus, even if they functionally don't"""
+    """No-blur windows will always appear to stay in focus, even if they functionally don't."""
 
     is_noresize = False
-    """No-resize windows cannot be resized using the mouse"""
+    """No-resize windows cannot be resized using the mouse."""
 
     is_dirty = False
-    """Control whether the parent manager needs to print this Window"""
+    """Control whether the parent manager needs to print this Window."""
+
+    min_width: int | None = None
+    """Minimum width of the window.
+
+    If set to none, _auto_min_width will be calculated based on the maximum width of inner widgets.
+    This is accurate enough for general use, but tends to lean to the safer side, i.e. it often
+    overshoots the 'real' minimum width possible.
+
+    If you find this to be the case, **AND** you can ensure that your window will not break, you
+    may set this value manually."""
 
     styles = {**Container.styles, **{"title": MarkupFormatter("[wm-title]{item}")}}
+    chars = Container.chars.copy()
 
     def __init__(self, *widgets: Any, **attrs: Any) -> None:
-        """Initialize object"""
+        """Initializes object.
+
+        Args:
+            widgets: Widgets to add to this window after initilization.
+            attrs: Attributes that are passed to the constructor.
+        """
+
+        self._auto_min_width = 0
 
         super().__init__(*widgets, **attrs)
 
@@ -217,28 +154,94 @@ class Window(Container):
             self.set_title(self.title)
 
     @property
-    def rect(self) -> Rect:
-        """Return Rect representing this window"""
+    def rect(self) -> tuple[int, int, int, int]:
+        """Returns the tuple of positions that define this window.
 
-        # TODO: This probably shouldn't be done every time.
-        return Rect.from_widget(self)
+        Returns:
+            A tuple of integers, in the order (left, top, right, bottom).
+        """
+
+        left, top = self.pos
+        return (left, top, left + self.width, top + self.height)
 
     @rect.setter
     def rect(self, new: tuple[int, int, int, int]) -> None:
-        """Set new rect"""
+        """Sets new position, width and height of this window.
+
+        This method also checks for the minimum width this window can be, and
+        if the new width doesn't comply with that setting the changes are thrown
+        away.
+
+        Args:
+            new: A tuple of integers in the order (left, top, right, bottom).
+        """
+
+        left, top, right, bottom = new
+        minimum = self.min_width or self._auto_min_width
+
+        if right - left < minimum:
+            return
 
-        left, top, right, _ = new.values
         self.pos = (left, top)
         self.width = right - left
+        self.height = bottom - top
 
     def __iadd__(self, other: object) -> Window:
-        """Call self._add_widget(other) and return self"""
+        """Calls self._add_widget(other) and returns self."""
 
         self._add_widget(other)
         return self
 
+    def __add__(self, other: object) -> Window:
+        """Calls self._add_widget(other) and returns self."""
+
+        self._add_widget(other)
+        return self
+
+    def _add_widget(self, other: object, run_get_lines: bool = True) -> Widget:
+        """Adds a widget to the window.
+
+        Args:
+            other: The widget-like to add.
+            run_get_lines: Whether self.get_lines should be ran after adding.
+        """
+
+        added = super()._add_widget(other, run_get_lines)
+
+        if self.min_width is None and len(self._widgets) > 0:
+            self._auto_min_width = max(widget.width for widget in self._widgets)
+
+        self.height += added.height
+
+        return added
+
+    def contains(self, pos: tuple[int, int]) -> bool:
+        """Determines whether widget contains `pos`.
+
+        This method uses window.rect to get the positions.
+
+        Args:
+            pos: Position to compare.
+
+        Returns:
+            Boolean describing whether the position is inside
+              this widget.
+        """
+
+        left, top, right, bottom = self.rect
+
+        return left <= pos[0] < right and top <= pos[1] < bottom
+
     def set_title(self, title: str, position: int = 0, pad: bool = True) -> None:
-        """Set window title"""
+        """Sets the window's title.
+
+        Args:
+            title: The string to set as the window title.
+            position: An integer indexing into ["left", "top", "right", "bottom"],
+                determining where the title is applied.
+            pad: Whether there should be an extra space before and after the given title.
+                defaults to True.
+        """
 
         self.title = title
 
@@ -259,7 +262,14 @@ class Window(Container):
         self.set_char("corner", corners)
 
     def set_fullscreen(self, value: bool = True) -> Window:
-        """Set window to fullscreen"""
+        """Sets window to fullscreen.
+
+        Args:
+            value: Whether fullscreen should be set or unset.
+
+        Returns:
+            The same window.
+        """
 
         if value:
             self._restore_data = self.pos, (self.width, self.height)
@@ -290,6 +300,7 @@ class Window(Container):
         """Instruct window manager to close object"""
 
         assert self.manager is not None
+
         self.manager.close(self)
 
     def print(self) -> None:
@@ -302,15 +313,23 @@ class Window(Container):
 
 
 class WindowManager(Container):
-    """A class representing a WindowManager"""
+    """A class representing a WindowManager."""
 
     is_bindable = True
 
     framerate = 120
     """Target framerate for rendering. Higher number means more resource usage."""
 
+    focusing_actions: list[MouseAction] = [
+        MouseAction.LEFT_CLICK,
+        MouseAction.LEFT_DRAG,
+        MouseAction.RIGHT_CLICK,
+        MouseAction.RIGHT_DRAG,
+    ]
+    """A list of MouseAction-s that, when executed over a non-focused window will focus it."""
+
     def __init__(self, **attrs: Any) -> None:
-        """Initialize object"""
+        """Initialize object."""
 
         super().__init__(**attrs)
 
@@ -339,7 +358,11 @@ class WindowManager(Container):
 
     @staticmethod
     def _sleep(duration: float) -> None:
-        """Accurately sleep some duration"""
+        """Accurately sleeps some duration.
+
+        Args:
+            duration: The amount to sleep.
+        """
 
         # TODO: Implement a better sleep function
 
@@ -347,7 +370,7 @@ class WindowManager(Container):
 
     @property
     def should_print(self) -> bool:
-        """Whether the `WindowManager` has dirty elements
+        """Returns whether the `WindowManager` has dirty elements.
 
         An element being "dirty" means it has changes not yet shown. Windows
         can set themselves to be dirty using the `Window.is_dirty` flag."""
@@ -355,12 +378,12 @@ class WindowManager(Container):
         return self._should_print or any(window.is_dirty for window in self._windows)
 
     def __enter__(self) -> WindowManager:
-        """Start context manager"""
+        """Starts context manager."""
 
         return self
 
     def __exit__(self, _: Any, exception: Exception, __: Any) -> bool:
-        """End context manager"""
+        """Ends context manager."""
 
         if exception is not None:
             raise exception
@@ -408,7 +431,14 @@ class WindowManager(Container):
         Thread(name="WM_DisplayLoop", target=_loop).start()
 
     def execute_binding(self, key: Any) -> bool:
-        """Execute bindings, including mouse ones"""
+        """Execute bindings, including mouse ones.
+
+        Args:
+            key: The binding to execute, if found.
+
+        Returns:
+            Boolean describing success.
+        """
 
         if not isinstance(key, str):
             return super().execute_binding(key)
@@ -438,7 +468,14 @@ class WindowManager(Container):
         return super().execute_binding(key)
 
     def handle_key(self, key: str) -> bool:
-        """Process a keypress"""
+        """Process a keypress.
+
+        Args:
+            key: The key to handle.
+
+        Returns:
+            A boolean describing success.
+        """
 
         # Apply WindowManager bindings
         if self.execute_binding(key):
@@ -455,17 +492,11 @@ class WindowManager(Container):
         return False
 
     def process_mouse(self, key: str) -> None:
-        """Process (potential) mouse input"""
+        """Processes (potential) mouse input.
 
-        def _get_target() -> Window | None:
-            """Get current drag target window"""
-
-            if self._drag_target is None:
-                return None
-
-            win = self._drag_target[0]
-            assert isinstance(win, Window) or win is None
-            return win
+        Args:
+            key: Input to handle.
+        """
 
         handlers = {
             MouseAction.LEFT_CLICK: self._click,
@@ -480,33 +511,33 @@ class WindowManager(Container):
             return
 
         for event in event_list:
-            target_window = _get_target()
-
             # Ignore null-events
             if event is None:
                 continue
 
-            # Mypy sees `event` as a tuple[MouseAction, tuple[int, int]] for some reason.
-            action, pos = cast(MouseEvent, event)
+            self._should_print = True
 
             for window in self._windows:
-                if window is target_window or window.rect.contains(pos):
-                    if action is not MouseAction.HOVER and not window.has_focus:
-                        self.focus(window)
+                contains_pos = window.contains(event.position)
 
-                    if (
-                        not window.handle_mouse(cast(MouseEvent, event))
-                        and action in handlers
-                    ):
-                        handlers[action](pos, window)
+                if contains_pos and event.action in self.focusing_actions:
+                    self.focus(window)
 
-                    self._should_print = True
-
-                    self.execute_binding((action, pos))
+                if window.handle_mouse(event):
                     break
 
+                if event.action in handlers and handlers[event.action](
+                    event.position, window
+                ):
+                    break
+
+                if not contains_pos and not window.is_modal:
+                    continue
+
+                self.execute_binding(tuple(event))
+
                 # Break on modal window
-                if window.is_modal:
+                if window.is_modal or contains_pos:
                     break
 
             # Unset drag_target if no windows received the input
@@ -514,7 +545,11 @@ class WindowManager(Container):
                 self._drag_target = None
 
     def focus(self, window: Window) -> None:
-        """Set a window to be focused"""
+        """Sets a window to be focused.
+
+        Args:
+            window: The window to focus.
+        """
 
         for other_window in self._windows:
             other_window.has_focus = False
@@ -530,7 +565,14 @@ class WindowManager(Container):
         self.focused = window
 
     def add(self, window: Window) -> WindowManager:
-        """Add a window to this manager"""
+        """Adds a window to this manager.
+
+        Args:
+            window: The window to add.
+
+        Returns:
+            self.
+        """
 
         self._windows.insert(0, window)
         self._should_print = True
@@ -543,15 +585,27 @@ class WindowManager(Container):
         return self
 
     def close(self, window: Window) -> None:
-        """Close a window"""
+        """Closes a window.
+
+        Args:
+            window: The window to close.
+        """
 
         self._windows.remove(window)
 
         if window.has_focus and len(self._windows) > 0:
             self.focus(self._windows[0])
 
+        # NOTE: This is supposed to work using `_should_print`, but it doesn't.
+        # Force print
+        self.print()
+
     def on_resize(self, size: tuple[int, int]) -> None:
-        """Correctly update window positions & print when terminal gets resized"""
+        """Correctly updates window positions & prints when terminal gets resized.
+
+        Args:
+            size: The new terminal size.
+        """
 
         width, height = size
 
@@ -564,20 +618,20 @@ class WindowManager(Container):
         self._should_print = True
 
     def _click(self, pos: tuple[int, int], window: Window) -> bool:
-        """Process clicking a window"""
+        """Process clicking a window."""
 
-        left, top, right, bottom = window.rect.values
+        left, top, right, bottom = window.rect
 
-        if pos[1] == top and left <= pos[0] <= right:
+        if pos[1] == top and left <= pos[0] < right:
             self._drag_target = (window, Edge.TOP)
 
-        elif pos[1] == bottom and left <= pos[0] <= right:
+        elif pos[1] == bottom - 1 and left <= pos[0] < right:
             self._drag_target = (window, Edge.BOTTOM)
 
-        elif pos[0] == left and top <= pos[1] <= bottom:
+        elif pos[0] == left and top <= pos[1] < bottom:
             self._drag_target = (window, Edge.LEFT)
 
-        elif pos[0] == right and top <= pos[1] <= bottom:
+        elif pos[0] == right - 1 and top <= pos[1] < bottom:
             self._drag_target = (window, Edge.RIGHT)
 
         else:
@@ -619,7 +673,7 @@ class WindowManager(Container):
         if window is not target_window:
             return False
 
-        left, top, right, bottom = window.rect.values
+        left, top, right, bottom = window.rect
         if not window.is_static and edge is Edge.TOP:
             window.pos = (
                 _clamp_pos(0),
@@ -628,21 +682,19 @@ class WindowManager(Container):
 
             handled = True
 
+        # TODO: Why are all these arbitrary offsets needed?
         elif not window.is_noresize:
             if edge is Edge.RIGHT:
-                window.rect = Rect.from_tuple((left, top, pos[0] + 1, bottom))
+                window.rect = (left, top, pos[0] + 1, bottom)
                 handled = True
 
             elif edge is Edge.LEFT:
-                window.rect = Rect.from_tuple(
-                    (pos[0], top, right + left - pos[0], bottom)
-                )
+                window.rect = (pos[0], top, right, bottom)
                 handled = True
 
-        try:
-            window.get_lines()
-        except LineLengthError:
-            window.rect = Rect.from_tuple((left, top, right, bottom))
+            elif edge is Edge.BOTTOM:
+                window.rect = (left, top, right, pos[1] + 1)
+                handled = True
 
         # Wipe window from cache
         if id(window) in self._window_cache:
@@ -654,13 +706,20 @@ class WindowManager(Container):
         """Process release of key"""
 
         self._drag_target = None
-        return True
+
+        # This return False so Window can handle the mouse action as well,
+        # as not much is done in this callback.
+        return False
 
     def process_input(self) -> None:
-        """Process incoming input"""
+        """Processes incoming input."""
 
         while self._is_running:
-            key = getch()
+            key = getch(interrupts=False)
+
+            if key == chr(3):
+                self.stop()
+                break
 
             if self.handle_key(key):
                 self._should_print = True
@@ -669,38 +728,47 @@ class WindowManager(Container):
             self.process_mouse(key)
 
     def stop(self) -> None:
-        """Stop main loop"""
+        """Stops the main loop."""
 
         self._is_running = False
 
     def pause(self) -> None:
-        """Pause main loop"""
+        """Pauses the main loop."""
 
         self._is_paused = True
 
     def unpause(self) -> None:
-        """Pause main loop"""
+        """Pauses the main loop."""
 
         self._is_paused = False
 
     def exit(self) -> None:
-        """Exit program"""
+        """Exits the program."""
 
         self.stop()
         sys.exit()
 
-    def run(self) -> None:
-        """Run main loop"""
+    def run(self, mouse_events: list[str] | None = None) -> None:
+        """Runs the main loop.
+
+        Args:
+            mouse_events: A list of mouse event types to listen to. See
+                `pytermgui.ansi_interface.report_mouse` for more information.
+                Defaults to `["press_hold", "hover"]`.
+        """
+
+        if mouse_events is None:
+            mouse_events = ["press_hold", "hover"]
 
         with alt_buffer(cursor=False, echo=False):
-            with mouse_handler(["press_hold", "hover"], "decimal_xterm") as translate:
+            with mouse_handler(mouse_events, "decimal_xterm") as translate:
                 self.mouse_translator = translate
                 self._start_display_thread()
 
                 self.process_input()
 
     def print(self) -> None:
-        """Print all windows"""
+        """Prints all windows."""
 
         def _get_lines(window: Window) -> list[str]:
             """Get cached or live lines from a Window"""
@@ -728,10 +796,7 @@ class WindowManager(Container):
                 window.height = terminal.height + 3
 
             if window.has_focus or window.is_noblur:
-                try:
-                    window.print()
-                except LineLengthError:
-                    pass
+                window.print()
                 continue
 
             lines = _get_lines(window)
@@ -742,12 +807,33 @@ class WindowManager(Container):
         sys.stdout.flush()
         self._should_print = False
 
-    def show_targets(self, color: int | None = None) -> None:
-        """Show all windows' targets"""
+    def show_targets(self) -> None:
+        """Shows all windows' positions."""
+
+        def _show_positions(widget, color_base: int = 60) -> None:
+            """Show positions of widget."""
+
+            if isinstance(widget, Container):
+                for i, subwidget in enumerate(widget):
+                    _show_positions(subwidget, color_base + i)
+
+                return
+
+            if not widget.is_selectable:
+                return
+
+            with cursor_at(widget.pos) as pprint:
+                debug = widget.debug()
+                buff = background(" ", color_base, reset_color=False)
+
+                for i in range(min(widget.width, real_length(debug)) - 1):
+                    buff += debug[i]
+
+                pprint(buff)
 
         self.pause()
-        for window in self._windows:
-            window.show_targets(color)
+        for widget in self._windows:
+            _show_positions(widget)
 
         getch()
         self.unpause()
@@ -755,7 +841,11 @@ class WindowManager(Container):
         self._should_print = True
 
     def alert(self, *content: Any) -> None:
-        """Create a modal window with content"""
+        """Create a modal window with content.
+
+        Args:
+            *content: The content to add to the new window.
+        """
 
         window = Window("[wm-title]Alert!", is_modal=True, width=50)
         for item in content:
